@@ -75,7 +75,7 @@ class DetectionParse:
         media_field = Field("media", field_type="media")
         sample_struct.add_field(media_field)  # 添加图像field
         sample_container = DataSample(sample_struct, self._class_domain)
-
+        annotation_option_flag = False
         for sample in tqdm(samples, desc="parsing samples ...."):
             sample_item = {}  # 存储当前样本信息
             media_info = sample["media"]
@@ -91,7 +91,8 @@ class DetectionParse:
                 gt_info = sample["ground_truth"]
             else:
                 gt_info = []
-                sample_struct.set_optional("annotations")
+                annotation_option_flag = True
+                # sample_struct.set_optional("annotations")
             annotations = []
             for gt in gt_info:
                 # 获取ann_id
@@ -117,6 +118,8 @@ class DetectionParse:
                     category_id = gt.pop("categories")[0]["category_id"]
                     category_name = self.raw_class_info[gt_type][category_id]  # 拿到category_name
                     gt_item["category"] = self._class_domain.index(category_name)
+                else:
+                    gt.pop("categories", [])
 
                 attributes = gt.pop("attributes", {})
                 for attr_k, attr_v in attributes.items():
@@ -142,6 +145,8 @@ class DetectionParse:
             annotation_field = Field("annotations", field_type="list",
                                      param=object_struct.as_others_param(sample_struct))
             sample_struct.add_field(annotation_field)  # 添加annotation field
+            if annotation_option_flag:
+                sample_struct.set_optional("annotations")
             return (object_struct, sample_struct), sample_container
         else:
             return (sample_struct,), sample_container
